setwd("___") #LOCAL ONDE ESTÁ A BASE BAIXADA


#Escolha o ano

for(ano in 2018:2020){
base<-read.csv2("pls_totais_R.csv",header=TRUE,dec = ",")
#Trabalhe apenas com os dados anuais
base<-base[base$periodicidade=="Anual"&base$ano==ano,]

#Temos que tirar alguns tribunais para o cálculo
sai.trib<-c("TRE","TJ","TRF1_2º Grau", "TRF2_2º Grau","TRF3_2º Grau",
             "TRF4_2º Grau","TRF5_2º Grau","TRF1_SJAM","TRF2_SJRJ","TRF4_SJSC", "TRF4_SJPR","TRF4_SJRS","TRF1_SJAC",
             "TRF1_SJAP","TRF1_SJBA","TRF1_SJDF","TRF1_SJRR","TRF1_SJRO","TRF1_SJPI","TRF1_SJMG","TRF1_SJMT",
             "TRF1_SJMA","TRF1_SJGO","TRF1_SJTO","TRF5_SJAL","TRF5_SJSE","TRF5_SJPE","TRF5_SJCE","TRF5_SJRN",
             "TRF5_SJPB","TRF2_SJES","TRF3_SJSP","TRF3_SJMS","TRF","TJM","PJ","TRT","Sup/Con","TRF1_SJPA")
base<-base[!base$tribunal %in% sai.trib,]

#O TRE-AM não informou as variáveis referentes a quantidade de veículos em 2020, logo ele não teve o seu IDS calculado neste ano.
if(ano==2020){
  base<-base[!base$tribunal=="TRE-AM",]
}


base <- sapply(base, gsub, pattern = ",", replacement= ".")
base<-data.frame(base)

#Variáveis
#1 - cre - Consumo de energia por metro quadrado
base$cre<-as.numeric(base$cre)
#2 - cra - Consumo de água por metro quadrado
base$cra<-as.numeric(base$cra)
#3 - upv - Usuário por veículo (vamos criar)
base$upv<-as.numeric(base$ftt)/as.numeric(base$qve)
#4 - cct.ftt - Consumo de copos descartáveis per capita
base$cct.ftt<-as.numeric(base$cct.ftt)
#5 - cp.ftt - Consumo de papel (resmas per capita)
base$cpt.ftt<-as.numeric(base$cpt.ftt)
#6 - tmr.ftt - Destinação de material para reciclagem per capita
base$tmr.ftt<-as.numeric(base$tmr)/as.numeric(base$ftt)
#7 - caenv - Consumo de água envasada descartável per capita
base$ced.ftt<-as.numeric(base$ced.ftt)
#8 - prqv - Participação relativa em ações de qualidade de vida
base$prqv<-as.numeric(base$prqv)
#9 - glinha - Gasto de Telefonia por linhas
base$glinha<-(as.numeric(base$gtf)+as.numeric(base$gtm))/(as.numeric(base$ltm)+as.numeric(base$ltf))
#10 - qei/ftt - Quantidade de equipamentos de impressão per capita
base$qei.ftt<-as.numeric(base$qei)/as.numeric(base$ftt)
#11 - prsc - Participação relativa em capacitação e sensibilização socioambiental
base$prsc<-as.numeric(base$prsc)
#12 - psc - Participação relativa em ações solidárias
base$prs<- as.numeric(base$prs)


#Padronizando pela Normal
base$normal_cra<-1-pnorm(base$cra,mean = mean(base$cra,na.rm = TRUE), sd = sd(base$cra,na.rm = TRUE))
base$normal_cre<-1-pnorm(base$cre,mean = mean(base$cre,na.rm = TRUE), sd = sd(base$cre,na.rm = TRUE))
base$normal_upv<-pnorm(base$upv,mean = mean(base$upv,na.rm = TRUE), sd = sd(base$upv,na.rm = TRUE)) #está em sentido oposto, pois quanto maior o indicador melhor
base$normal_cct.ftt<-1-pnorm(base$cct.ftt,mean = mean(base$cct.ftt,na.rm = TRUE), sd = sd(base$cct.ftt,na.rm = TRUE))
base$normal_cpt.ftt<-1-pnorm(base$cpt.ftt,mean = mean(base$cpt.ftt,na.rm = TRUE), sd = sd(base$cpt.ftt,na.rm = TRUE))
base$normal_tmr.ftt<-pnorm(base$tmr.ftt,mean = mean(base$tmr.ftt,na.rm = TRUE), sd = sd(base$tmr.ftt,na.rm = TRUE)) #está em sentido oposto, pois quanto maior o indicador melhor
base$normal_ced.ftt<-1-pnorm(base$ced.ftt,mean = mean(base$ced.ftt,na.rm = TRUE), sd = sd(base$ced.ftt,na.rm = TRUE))
base$normal_prqv<-pnorm(base$prqv,mean = mean(base$prqv,na.rm = TRUE), sd = sd(base$prqv,na.rm = TRUE)) #está em sentido oposto, pois quanto maior o indicador melhor
base$normal_glinha<-1-pnorm(base$glinha,mean = mean(base$glinha,na.rm = TRUE), sd = sd(base$glinha,na.rm = TRUE))
base$normal_qei.ftt<-1-pnorm(base$qei.ftt,mean = mean(base$qei.ftt,na.rm = TRUE), sd = sd(base$qei.ftt,na.rm = TRUE))
base$normal_prsc<-pnorm(base$prsc,mean = mean(base$prsc,na.rm = TRUE), sd = sd(base$prsc,na.rm = TRUE)) #está em sentido oposto, pois quanto maior o indicador melhor
base$normal_prs<-pnorm(base$prs,mean = mean(base$prs,na.rm = TRUE), sd = sd(base$prs,na.rm = TRUE)) #está em sentido oposto, pois quanto maior o indicador melhor

#É necessário a inserção do valor 0 na existência de valor NA nesta variável, pois isto acontece quando o tribunal não implementou as ações (aqv,asc,as) no ano de referência
base$normal_prqv<-ifelse(is.na(base$normal_prqv),0,base$normal_prqv)
base$normal_prsc<-ifelse(is.na(base$normal_prsc),0,base$normal_prsc)
base$normal_prs<-ifelse(is.na(base$normal_prs),0,base$normal_prs)

#Pesos da AHP
pesos<-c(
  2.147017018, #Consumo de energia por metro quadrado
  2.147017018, #Consumo de agua por metro quadrado
  0.831282477, #Usuário por veículo
  1.346212591, #Consumo de copos descartáveis
  1.346212591, #Consumo de papel (resmas per capita)
  0.831282477, #Destinação de material para reciclagem per capita
  1.346212591, #Consumo de água envasada descartável per capita
  0.323792664, #Participação relativa em ações de qualidade de vida
  0.516692624, #Gasto de Telefonia por linhas
  0.516692624, #Quantidade de equipamentos de impressão per capita
  0.323792664, #Participação relativa em capacitação e sensibilização socioambiental
  0.323792664  #Participação relativa em ações solidárias
  )

#Calcula-se o IDS para todos os tribunais
base$ids<-(base$normal_cre*pesos[1]+
  base$normal_cra*pesos[2]+
  base$normal_upv*pesos[3]+
  base$normal_cct.ftt*pesos[4]+
  base$normal_cpt.ftt*pesos[5]+
  base$normal_tmr.ftt*pesos[6]+
  base$normal_ced.ftt*pesos[7]+
  base$normal_prqv*pesos[8]+
  base$normal_glinha*pesos[9]+
  base$normal_qei.ftt*pesos[10]+
  base$normal_prsc*pesos[11]+
  base$normal_prs*pesos[12])/sum(pesos)

if(ano==2018){
  baseids_2018<-base
}else{if(ano==2019){
  baseids_2019<-base
}else{baseids_2020<-base}}
base<-NULL
}
baseids_2018<-baseids_2018[,c("tribunal","ids")]
baseids_2019<-baseids_2019[,c("tribunal","ids")]
baseids_2020<-baseids_2020[,c("tribunal","ids")]

names(baseids_2018)[2]<-"ids_2018"
names(baseids_2019)[2]<-"ids_2019"
names(baseids_2020)[2]<-"ids_2020"

baseids<-merge(baseids_2018,baseids_2019,by="tribunal")
baseids<-merge(baseids,baseids_2020,by="tribunal",all.x=TRUE)

write.csv2(baseids,"Resultado IDS - 2018 a 2020.csv",row.names = FALSE,na = "-")



